==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PolarLineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
/**
 * @hidden
 */
export let PolarLineSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesBaseDescriptionMetadata.a == null) {
                PolarLineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesBaseDescriptionMetadata.c(PolarLineSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(PolarLineSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(PolarLineSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            PolarBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PolarLineSeriesBaseDescriptionMetadata.b(a);
            a.ab("PolarLineSeriesBase", PolarLineSeriesBaseDescriptionMetadata.a);
        }
    }
    PolarLineSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarLineSeriesBaseDescriptionMetadata, 'PolarLineSeriesBaseDescriptionMetadata');
    PolarLineSeriesBaseDescriptionMetadata.a = null;
    return PolarLineSeriesBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PolarLineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
/**
 * @hidden
 */
export let PolarLineSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarLineSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (PolarLineSeriesBaseDescriptionMetadata.a == null) {
                PolarLineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarLineSeriesBaseDescriptionMetadata.c(PolarLineSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(PolarLineSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(PolarLineSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            PolarBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PolarLineSeriesBaseDescriptionMetadata.b(a);
            a.ad("PolarLineSeriesBase", PolarLineSeriesBaseDescriptionMetadata.a);
        }
    }
    PolarLineSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarLineSeriesBaseDescriptionMetadata, 'PolarLineSeriesBaseDescriptionMetadata');
    PolarLineSeriesBaseDescriptionMetadata.a = null;
    return PolarLineSeriesBaseDescriptionMetadata;
})();
